@@ -1,8 +1,9 @@
 from bokeh.models import Tooltip
 from bokeh.models.layouts import LayoutDOM, UIElement
 from bokeh.core.properties import Instance, Required, Float, Int, Either
+from .. import BokehInit
 
-class Tip(LayoutDOM):
+class Tip(LayoutDOM,BokehInit):
     '''Display a tooltip for the child element
     '''
 
